@@ -4,7 +4,7 @@
     */
     
     var RATIOS = {{ BETTY_RATIOS|safe }};
-    var breakpoints = [0,{{ BETTY_WIDTHS|join:","}}];
+    var breakpoints = [{{ BETTY_WIDTHS|join:","}}];
     function tmpl(text, dict) {
         for (var k in dict) {
             text = text.replace("{" + k + "}", dict[k]);
